Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EndpointIDFromRequest ¶
EndpointIDFromRequest returns the endpoint ID from the HTTP request, or an empty string if no endpoint ID is specified.
This will check both the 'x-piko-endpoint' header and 'Host' header, where x-piko-endpoint takes precedence.
Types ¶
type HTTPProxy ¶
type HTTPProxy struct {
// contains filtered or unexported fields
}
HTTPProxy proxies HTTP traffic to upsteam listeners.
func NewHTTPProxy ¶
func (*HTTPProxy) ServeHTTPWithUpstream ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
func NewServer ¶
func NewServer( upstreams upstream.Manager, proxyConfig config.ProxyConfig, registry *prometheus.Registry, verifier *auth.MultiTenantVerifier, tlsConfig *tls.Config, logger log.Logger, ) *Server
type TCPProxy ¶
type TCPProxy struct {
// contains filtered or unexported fields
}
TCPProxy proxies TCP traffic to upstream listeners.
Incoming TCP traffic is sent over WebSockets by a Piko client, then forwarded to an upstream via a multiplexed stream.
func NewTCPProxy ¶
Click to show internal directories.
Click to hide internal directories.